@@ -4,11 +4,12 @@ import (
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/redshift"
+	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
 )
 
 type RedshiftSnapshot struct {
-	svc                *redshift.Redshift
-	snapshotIdentifier *string
+	svc      *redshift.Redshift
+	snapshot *redshift.Snapshot
 }
 
 func init() {
@@ -31,8 +32,8 @@ func ListRedshiftSnapshots(sess *session.Session) ([]Resource, error) {
 
 		for _, snapshot := range output.Snapshots {
 			resources = append(resources, &RedshiftSnapshot{
-				svc:                svc,
-				snapshotIdentifier: snapshot.SnapshotIdentifier,
+				svc:      svc,
+				snapshot: snapshot,
 			})
 		}
 
@@ -46,15 +47,26 @@ func ListRedshiftSnapshots(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
+func (f *RedshiftSnapshot) Properties() types.Properties {
+	properties := types.NewProperties().
+		Set("CreatedTime", f.snapshot.SnapshotCreateTime)
+
+	for _, tag := range f.snapshot.Tags {
+		properties.SetTag(tag.Key, tag.Value)
+	}
+
+	return properties
+}
+
 func (f *RedshiftSnapshot) Remove() error {
 
 	_, err := f.svc.DeleteClusterSnapshot(&redshift.DeleteClusterSnapshotInput{
-		SnapshotIdentifier: f.snapshotIdentifier,
+		SnapshotIdentifier: f.snapshot.SnapshotIdentifier,
 	})
 
 	return err
 }
 
 func (f *RedshiftSnapshot) String() string {
-	return *f.snapshotIdentifier
+	return *f.snapshot.SnapshotIdentifier
 }
